.g-collection-list-entry

  .g-collection-title
    font-size 17px

  .g-collection-right-column
    border-left 1px solid #ddd
    padding-left 8px
    display inline
    width 290px
    font-size 14px
    float right
    color #909090

  .g-collection-description
    background-color white
    padding 8px 12px
    border-radius 3px
    border 1px solid #dedede

.g-collection-list-header
  padding-bottom 10px

  .g-collection-pagination
    display inline-block
    >ul
      margin 0 15px 0 0

    .pagination>li>a
      float none
      line-height 1.5
      padding 7px 12px

  .g-collection-search-form
    display inline
    margin-right 15px

    .form-group
      display inline-block
