.g-group-header
  border-bottom 1px solid #ddd
  margin-bottom 15px

.g-group-tabs
  margin-top 18px

.g-group-description
  min-height 15px

.g-group-status-container
  margin-top 5px
  color #777
  padding 6px 8px
  border-radius 3px
  box-shadow 1px 1px 3px 2px #f5f5f5

  &.g-member
    background-color #edffed
    border 1px solid #cdedcd
  &.g-invited
    background-color #fffed8
    border 1px solid #e5e2c8
  &.g-nonmember
    background-color #eee
    border 1px solid #ddd
  &.g-requested-invite
    background-color #edffed
    border 1px solid #cdedcd
  &.g-admin
    background-color #edffed
    border 1px solid #cdedcd

  > a
    font-weight bold

.g-group-members-container
.g-group-requests-container
.g-group-admins-container
.g-group-mods-container
  margin-top 15px

.g-group-members
.g-group-mods
.g-group-admins
.g-group-requests
.g-group-invites
  list-style-type none
  padding 0
  margin-bottom 20px

  >li
    border-bottom 1px solid #f0f0f0
    background-color #fbfbfb
    padding 5px

.g-group-list-header
  background-color #f0f0f0
  padding 4px 5px
  color #555
  border-bottom 1px solid #ddd

.g-member-pagination>ul
  margin 5px 0

.g-group-member-controls
  >a
  span>a
    font-size 15px
    margin-left 4px
    border 1px solid #d5d5d5
    border-radius 3px
    padding 2px 3px
    color #555

    &:hover
      border 1px solid #aaa
      background-color #dadada
      color #222

.g-group-invite-form
  display inline-block
  margin-left 15px
  border-left 1px solid #d7d7d7
  padding-left 15px

  .g-group-invite-container
    margin-left 5px
    margin-bottom 0
    display inline-block !important

.g-member-pagination
  display inline-block
  margin-left 15px
  padding-left 15px
  border-left 1px solid #d7d7d7
  .pagination>li>a
    line-height 1.5
    float none
    padding 7px 12px

.g-member-list-empty
  margin-top 5px
  background-color #fffee1
  color #777
  padding 6px 8px
  border-radius 3px
  border 1px solid #e5e2c8
  box-shadow 1px 1px 3px 2px #f5f5f5

#g-invite-role-container
  .g-add-user-button
    margin-left 10px

#g-group-tab-pending-status
  display inline
